words = ['aan', 'aandacht', 'aandoen', 'aangedaan', 'aangenaam', 'aangevallen',
         'aankomen', 'aannemen', 'aantal', 'aanval', 'aanvallen', 'aarde',
         'aardig', 'absoluut', 'ach', 'acht', 'achter', 'achtergelaten',
         'achteruit', 'actie', 'adam', 'adem', 'adres', 'advies', 'advocaat',
         'af', 'afdeling', 'afgelopen', 'afgesproken', 'afmaken', 'afscheid',
         'afspraak', 'afstand', 'agent', 'agenten', 'ah', 'akkoord', 'al',
         'alan', 'alarm', 'alex', 'alice', 'alle', 'allebei', 'alleen',
         'allemaal', 'allen', 'alles', 'als', 'alsjeblieft', 'alsof',
         'alstublieft', 'altijd', 'alweer', 'amerika', 'amerikaanse',
         'amerikanen', 'and', 'ander', 'andere', 'anderen', 'anders', 'andy',
         'angst', 'anna', 'antwoord', 'antwoorden', 'appartement', 'arm',
         'arme', 'armen', 'arresteren', 'arthur', 'arts', 'auto',
         'avond', 'baan', 'baas', 'baby', 'bad', 'badkamer', 'bak', 'bal',
         'ballen', 'band', 'bang', 'bank', 'bar', 'basis', 'bauer', 'bed',
         'bedacht', 'bedanken', 'bedankt', 'bedenken', 'bedoel', 'bedoelde',
         'bedoeling', 'bedoelt', 'bedrijf', 'beeld', 'beelden', 'been',
         'beest', 'beetje', 'begin', 'beginnen', 'begint', 'begon', 'begonnen',
         'begrafenis', 'begraven', 'begrepen', 'begrijp', 'begrijpen',
         'begrijpt', 'behalve', 'behandelen', 'behoorlijk', 'beide', 'beiden',
         'bek', 'bekend', 'bekijk', 'bekijken', 'bel', 'belachelijk',
         'belangrijk', 'belangrijke', 'belangrijkste', 'belde', 'bellen',
         'beloof', 'beloofd', 'belt', 'ben', 'bende', 'beneden', 'benen',
         'bent', 'bepaald', 'bepaalde', 'bereid', 'bereiken', 'bereikt',
         'berg', 'bergen', 'bericht', 'beschermen', 'beslissen', 'beslissing',
         'beslist', 'besloten', 'bespreken', 'best', 'bestaan', 'bestaat',
         'beste', 'betaal', 'betaald', 'betaalt', 'betalen', 'betekenen',
         'betekent', 'beter', 'betere', 'betreft', 'betrokken', 'beurt',
         'bevalt', 'beveiliging', 'bevel', 'bewegen', 'beweging', 'bewijs',
         'bewijzen', 'bezig', 'bezit', 'bezoek', 'bezorgd', 'bidden', 'bieden',
         'bier', 'big', 'bij', 'bijna', 'bijvoorbeeld', 'bijzonder', 'bill',
         'billy', 'binnen', 'binnenkort', 'black', 'blanke', 'blauw', 'blauwe',
         'bleef', 'blij', 'blijf', 'blijft', 'blijkbaar', 'blijkt', 'blijven',
         'blik', 'blind', 'bloed', 'bloemen', 'bob', 'bobby', 'boek', 'boeken',
         'boel', 'bom', 'boodschap', 'boom', 'boord', 'boos', 'boot', 'borst',
         'bos', 'bouwen', 'boven', 'bracht', 'brand', 'breken', 'breng',
         'brengen', 'brengt', 'brian', 'brief', 'broeder', 'broek', 'broer',
         'broers', 'bron', 'brug', 'bruiloft', 'buiten', 'bureau', 'burgemeester',
         'bus', 'buurt', 'camera', 'captain', 'carl', 'carter', 'cel', 'cent',
         'charles', 'charlie', 'chef', 'chicago', 'chloe', 'chris', 'christus',
         'chuck', 'cia', 'city', 'claire', 'clark', 'club', 'coach', 'code',
         'com', 'commandant', 'compleet', 'computer', 'contact', 'contract',
         'controle', 'controleer', 'controleren', 'cool', 'daar',
         'daardoor', 'daarmee', 'daarna', 'daarom', 'daarvan', 'daarvoor',
         'dacht', 'dachten', 'dader', 'dag', 'dagen', 'dak', 'dame', 'dames',
         'dan', 'daniel', 'dank', 'dankbaar', 'dankzij', 'danny', 'dans',
         'dansen', 'dat', 'data', 'dave', 'david', 'de', 'deal', 'deden',
         'deed', 'deel', 'degene', 'delen', 'denk', 'denken', 'denkt', 'der',
         'derde', 'des', 'details', 'deur', 'deuren', 'deze', 'dezelfde',
         'dicht', 'dichtbij', 'dichterbij', 'die', 'dienst', 'diep', 'dieren',
         'dik', 'dikke', 'ding', 'dingen', 'direct', 'directeur', 'dit',
         'dna', 'doc', 'dochter', 'dode', 'doden', 'doe', 'doel', 'doelwit',
         'doen', 'doet', 'dokter', 'dol', 'dollar', 'dom', 'domme', 'don',
         'donder', 'donker', 'dood', 'door', 'doorgaan', 'doorheen', 'doos',
         'dorp', 'dossier', 'dr', 'draag', 'draagt', 'draai', 'draaien',
         'draait', 'dragen', 'drank', 'drankje', 'drie', 'drink', 'drinken',
         'droeg', 'dromen', 'dronken', 'droom', 'drugs', 'druk', 'duidelijk',
         'duivel', 'duizend', 'duizenden', 'duren', 'durf', 'dus', 'duur',
         'duurt', 'echt', 'echte', 'echtgenoot', 'ed', 'eddie', 'edelachtbare',
         'een', 'eenheid', 'eenmaal', 'eens', 'eentje', 'eer', 'eerder',
         'eerlijk', 'eerst', 'eerste', 'eet', 'eeuwig', 'eh', 'eigen',
         'eigenaar', 'eigenlijk', 'eikel', 'eiland', 'eind', 'einde',
         'eindelijk', 'elf', 'elk', 'elkaar', 'elke', 'emily', 'en', 'ene',
         'energie', 'eng', 'engeland', 'engels', 'enig', 'enige', 'enkel',
         'enkele', 'enorm', 'enorme', 'er', 'eraan', 'erachter', 'eraf',
         'erbij', 'erg', 'ergens', 'erger', 'ergste', 'eric', 'erin', 'ermee',
         'ernstig', 'erom', 'erop', 'erover', 'eruit', 'ervan', 'ervaring',
         'ervoor', 'eten', 'even', 'ex', 'excuseer', 'excuses', 'extra',
         'familie', 'fantastisch', 'favoriete', 'fbi', 'feest', 'feestje',
         'feit', 'fijn', 'fijne', 'film', 'films', 'flat', 'fles', 'foto',
         'fout', 'fouten', 'frank', 'fuck', 'ga', 'gaaf', 'gaan',
         'gaande', 'gaat', 'gaf', 'gang', 'gast', 'gasten', 'gat', 'gaten',
         'gauw', 'gave', 'gaven', 'gearresteerd', 'gebeld', 'gebeurd',
         'gebeurde', 'gebeuren', 'gebeurt', 'gebied', 'gebleven', 'geboren',
         'gebouw', 'gebouwd', 'gebracht', 'gebroken', 'gebruik', 'gebruiken',
         'gebruikt', 'gebruikte', 'gedaan', 'gedacht', 'gedachte', 'gedachten',
         'gedeelte', 'gedoe', 'gedood', 'gedownload', 'gedrag', 'gedragen',
         'geduld', 'geef', 'geeft', 'geen', 'geest', 'geesten', 'gefeliciteerd',
         'gegaan', 'gegeten', 'gegeven', 'gegevens', 'gehaald', 'gehad',
         'geheim', 'geheime', 'geheimen', 'geheugen', 'geholpen', 'gehoord',
         'gehouden', 'gek', 'gekke', 'gekocht', 'gekomen', 'gekozen',
         'gekregen', 'gelaten', 'geld', 'geleden', 'geleerd', 'gelezen',
         'gelijk', 'gelogen', 'geloof', 'geloofde', 'gelooft', 'geloven',
         'geluid', 'geluk', 'gelukkig', 'gelukt', 'gelul', 'gemaakt',
         'gemakkelijk', 'gemeen', 'gemist', 'genaamd', 'generaal', 'genezen',
         'geniet', 'genoeg', 'genoegen', 'genoemd', 'genomen', 'george',
         'gepakt', 'gepraat', 'geprobeerd', 'geraakt', 'gered', 'gereed',
         'geregeld', 'geschiedenis', 'geschoten', 'geschreven', 'geslagen',
         'geslapen', 'gesloten', 'gespeeld', 'gesprek', 'gesproken', 'gestolen',
         'gestoord', 'gestopt', 'gestorven', 'gestuurd', 'getrouwd', 'getuige',
         'getuigen', 'gevaar', 'gevaarlijk', 'geval', 'gevallen', 'gevangen',
         'gevangene', 'gevangenen', 'gevangenis', 'gevecht', 'geven', 'gevoel',
         'gevoelens', 'gevolgd', 'gevonden', 'gevraagd', 'gewacht', 'geweer',
         'geweest', 'geweld', 'geweldig', 'geweldige', 'gewerkt', 'geweten',
         'gewond', 'gewone', 'gewonnen', 'gewoon', 'geworden', 'gezegd',
         'gezelschap', 'gezet', 'gezeten', 'gezicht', 'gezien', 'gezin',
         'gezocht', 'gezond', 'ging', 'gingen', 'gisteravond', 'gisteren',
         'glas', 'god', 'goden', 'godsnaam', 'godverdomme', 'goed', 'goede',
         'goedemorgen', 'goedenavond', 'goeie', 'gooi', 'gooien', 'goud',
         'gouden', 'gozer', 'graag', 'graden', 'grap', 'grapje', 'grappig',
         'gratis', 'grens', 'groene', 'groep', 'grond', 'groot', 'grootste',
         'grote', 'groter', 'haal', 'haalt', 'haar', 'haast', 'haat', 'had',
         'hadden', 'halen', 'half', 'hallo', 'halve', 'hand', 'handen',
         'hangen', 'hangt', 'hard', 'harde', 'harder', 'harry', 'hart',
         'hartelijk', 'he', 'heb', 'hebben', 'hebt', 'heeft', 'heel', 'heen',
         'heer', 'heerlijk', 'heet', 'heilige', 'hel', 'helaas', 'held',
         'hele', 'helemaal', 'helft', 'help', 'helpen', 'helpt', 'hem',
         'hemel', 'hemelsnaam', 'hen', 'henry', 'heren', 'herinner',
         'herinneren', 'herinneringen', 'herinnert', 'hersenen', 'het',
         'hetzelfde', 'heus', 'hey', 'hield', 'hielp', 'hier', 'hierheen',
         'hiermee', 'hiervan', 'hiervoor', 'hij', 'hoe', 'hoed', 'hoef',
         'hoeft', 'hoek', 'hoelang', 'hoer', 'hoeveel', 'hoeven', 'hoewel',
         'hoezo', 'hoge', 'hoger', 'hoi', 'homo', 'hond', 'honden', 'honderd',
         'honger', 'hoofd', 'hoog', 'hoogte', 'hoop', 'hoopte', 'hoor',
         'hoorde', 'hoort', 'hopelijk', 'hopen', 'horen', 'hotel', 'hou',
         'houd', 'houden', 'houdt', 'huid', 'huilen', 'huis', 'hulp', 'hun',
         'huwelijk', 'idee', 'idioot', 'ie', 'ieder', 'iedere', 'iedereen',
         'iemand', 'iets', 'ijs', 'ik', 'in', 'inderdaad', 'indruk', 'ineens',
         'informatie', 'inspecteur', 'interessant', 'is', 'ja', 'jaar',
         'jack', 'jackson', 'jagen', 'jake', 'jaloers', 'james', 'jammer',
         'jane', 'jaren', 'jas', 'jason', 'jawel', 'jazeker', 'je', 'jerry',
         'jezelf', 'jezus', 'jij', 'jim', 'jimmy', 'joe', 'joey', 'john',
         'johnny', 'jones', 'jong', 'jonge', 'jongen', 'jongens', 'jou',
         'jouw', 'jouwe', 'juffrouw', 'juist', 'juiste', 'jullie', 'jurk',
         'kaart', 'kaarten', 'kalm', 'kamer', 'kamp', 'kan', 'kans', 'kant',
         'kantoor', 'kapitein', 'kapot', 'kast', 'kat', 'kate', 'keek',
         'keer', 'kelder', 'kelly', 'ken', 'kende', 'kennen', 'kennis',
         'kent', 'kerel', 'kerels', 'keren', 'kerk', 'kerstmis', 'keuken',
         'keus', 'keuze', 'kevin', 'kies', 'kiezen', 'kijk', 'kijken',
         'kijkt', 'kilo', 'kilometer', 'kind', 'kinderen', 'king', 'kip',
         'klaar', 'klant', 'klanten', 'klas', 'klein', 'kleine', 'kleren',
         'kleur', 'klinkt', 'klootzak', 'klootzakken', 'klopt', 'klote',
         'kluis', 'klus', 'km', 'knap', 'knul', 'koers', 'koffer', 'koffie',
         'kogel', 'kogels', 'koken', 'kolonel', 'kom', 'komaan', 'komen',
         'komt', 'kon', 'konden', 'koning', 'koningin', 'kont', 'koop',
         'kop', 'kopen', 'kort', 'korte', 'kost', 'kosten', 'koud', 'kracht',
         'krachten', 'krant', 'kreeg', 'kregen', 'krijg', 'krijgen', 'krijgt',
         'kun', 'kunnen', 'kunst', 'kunt', 'kus', 'kussen', 'kwaad', 'kwalijk',
         'kwam', 'kwamen', 'kwestie', 'kwijt', 'la', 'laag', 'laat', 'laatst',
         'laatste', 'lab', 'lach', 'lachen', 'lag', 'land', 'landen', 'lang',
         'lange', 'langer', 'langs', 'langzaam', 'larry', 'las', 'last',
         'lastig', 'laten', 'later', 'ledereen', 'lee', 'leef', 'leeft',
         'leeftijd', 'leeg', 'leek', 'leer', 'leerde', 'lees', 'leg', 'leger',
         'leggen', 'leiden', 'leider', 'leiding', 'leidt', 'lekker', 'lenen',
         'leren', 'les', 'let', 'leugen', 'leugenaar', 'leuk', 'leuke',
         'leven', 'levend', 'levens', 'lezen', 'lichaam', 'licht', 'lid',
         'liedje', 'lief', 'liefde', 'liefje', 'liefste', 'lieg', 'liegen',
         'liegt', 'liep', 'liet', 'lieve', 'liever', 'lieverd', 'lift',
         'liggen', 'ligt', 'lijden', 'lijk', 'lijken', 'lijkt', 'lijn',
         'lijst', 'links', 'lisa', 'lk', 'ln', 'locatie', 'logisch', 'lol',
         'londen', 'loop', 'loopt', 'lopen', 'lord', 'los', 'lot', 'ls',
         'lucht', 'lucy', 'lui', 'luister', 'luisteren', 'luistert',
         'luitenant', 'lukken', 'lukt', 'lul', 'lunch', 'ma', 'maak',
         'maakt', 'maakte', 'maan', 'maand', 'maanden', 'maar', 'maat',
         'maatje', 'machine', 'macht', 'mag', 'magie', 'majesteit', 'majoor',
         'maken', 'makkelijk', 'makkelijker', 'mam', 'mama', 'man', 'manier',
         'manieren', 'mannen', 'marcus', 'maria', 'mark', 'martin', 'mary',
         'matt', 'max', 'me', 'medicijnen', 'medische', 'mee', 'meegemaakt',
         'meegenomen', 'meen', 'meenemen', 'meer', 'meest', 'meestal',
         'meeste', 'meester', 'meid', 'meiden', 'meisje', 'meisjes', 'melk',
         'men', 'meneer', 'mening', 'mens', 'menselijk', 'menselijke',
         'mensen', 'mes', 'met', 'meteen', 'meter', 'mevr', 'mevrouw',
         'mexico', 'mezelf', 'michael', 'midden', 'mij', 'mijn', 'mijne',
         'mijnheer', 'mike', 'militaire', 'miljoen', 'miljoenen', 'minder',
         'minister', 'minuten', 'minuut', 'mis', 'misdaad', 'miss', 'misschien',
         'missen', 'missie', 'mist', 'mocht', 'moe', 'moed', 'moeder',
         'moeders', 'moeilijk', 'moeite', 'moest', 'moesten', 'moet', 'moeten',
         'mogelijk', 'mogen', 'moment', 'momentje', 'mond', 'monster', 'mooi',
         'mooie', 'mooiste', 'moord', 'moorden', 'moordenaar', 'morgen',
         'motor', 'mr', 'mrs', 'muur', 'muziek', 'na', 'naam', 'naar',
         'naartoe', 'naast', 'nacht', 'nachts', 'nadat', 'nadenken',
         'nagedacht', 'nam', 'namen', 'natuurlijk', 'nauwelijks', 'nee',
         'neef', 'neem', 'neemt', 'neen', 'neer', 'neergeschoten', 'negen',
         'nek', 'nemen', 'nergens', 'nerveus', 'net', 'neuken', 'neus',
         'new', 'nick', 'niemand', 'niet', 'niets', 'nietwaar', 'nieuw',
         'nieuwe', 'nieuws', 'niks', 'niveau', 'nodig', 'noem', 'noemde',
         'noemen', 'noemt', 'nog', 'nogal', 'nogmaals', 'nooit', 'noorden',
         'normaal', 'normale', 'nou', 'nu', 'nummer', 'ochtend', 'of',
         'officier', 'ogen', 'oh', 'ok', 'okay', 'oke', 'om', 'oma', 'omdat',
         'omgeving', 'omhoog', 'ondanks', 'onder', 'ondertitel', 'ondertiteling',
         'onderweg', 'onderzoek', 'onderzoeken', 'ongelofelijk', 'ongelooflijk',
         'ongeluk', 'ongeveer', 'onmiddellijk', 'onmogelijk', 'ons',
         'onschuldig', 'ontbijt', 'ontdekt', 'ontmoet', 'ontmoeten',
         'ontmoette', 'ontslagen', 'ontsnappen', 'ontsnapt', 'ontvangen',
         'ontvoerd', 'onze', 'onzin', 'oog', 'ooit', 'ook', 'oom', 'oorlog',
         'op', 'opa', 'opdracht', 'opeens', 'open', 'openen', 'operatie',
         'opgewonden', 'ophalen', 'ophouden', 'oplossen', 'oplossing',
         'opnemen', 'opnieuw', 'opschieten', 'opstaan', 'opzij', 'orde',
         'orders', 'oren', 'oud', 'oude', 'ouder', 'ouders', 'ouwe', 'over',
         'overal', 'overkomen', 'overleden', 'overleven', 'pa', 'paar',
         'paard', 'paarden', 'pad', 'pak', 'pakken', 'pakt', 'paniek', 'pap',
         'papa', 'papier', 'papieren', 'pardon', 'parijs', 'park', 'partner',
         'pas', 'passen', 'past', 'paul', 'per', 'perfect', 'perfecte',
         'pers', 'persoon', 'persoonlijk', 'persoonlijke', 'pete', 'peter',
         'pijn', 'piloot', 'pistool', 'plaats', 'plaatsen', 'plan', 'planeet',
         'plannen', 'plek', 'plezier', 'politie', 'pond', 'poort', 'positie',
         'post', 'praat', 'prachtig', 'prachtige', 'praten', 'precies',
         'president', 'prijs', 'prima', 'prins', 'prinses', 'probeer',
         'probeerde', 'probeert', 'proberen', 'probleem', 'problemen',
         'procent', 'proces', 'professor', 'programma', 'project', 'publiek',
         'punt', 'punten', 'raad', 'raak', 'raakt', 'raakte', 'raam', 'raar',
         'rachel', 'radio', 'raken', 'rapport', 'rare', 'ray', 'rechercheur',
         'recht', 'rechter', 'rechts', 'red', 'redden', 'reden', 'redt',
         'reed', 'reet', 'regel', 'regelen', 'regels', 'regering', 'reis',
         'reizen', 'reken', 'rekening', 'relatie', 'ren', 'rennen', 'respect',
         'rest', 'restaurant', 'richard', 'richting', 'rij', 'rijden',
         'rijdt', 'rijk', 'ring', 'risico', 'rivier', 'robert', 'rode',
         'roep', 'roepen', 'roken', 'rol', 'rome', 'rond', 'rood', 'rook',
         'rot', 'rotzooi', 'rug', 'ruik', 'ruikt', 'ruim', 'ruimte', 'rust',
         'rusten', 'rustig', 'ruzie', 'ryan', 'saai', 'sam', 'samen', 'san',
         'sarah', 'schade', 'schat', 'schatje', 'schattig', 'schelen',
         'schepen', 'schiet', 'schieten', 'schijnt', 'schip', 'schoenen',
         'school', 'schoon', 'schoonheid', 'schoot', 'schot', 'schreef',
         'schrijf', 'schrijven', 'schuld', 'schuldig', 'scott', 'sean',
         'seconden', 'seks', 'senator', 'sergeant', 'serieus', 'sexy',
         'sheriff', 'shirt', 'shit', 'show', 'signaal', 'simon', 'simpel',
         'sinds', 'sir', 'situatie', 'sla', 'slaan', 'slaap', 'slaapt',
         'slaat', 'slachtoffer', 'slachtoffers', 'slag', 'slapen', 'slecht',
         'slechte', 'slechts', 'sleutel', 'sleutels', 'slim', 'sloeg', 'slot',
         'sluit', 'sluiten', 'smith', 'snap', 'snapt', 'snel', 'snelheid',
         'sneller', 'soldaat', 'soldaten', 'sommige', 'sommigen', 'soms',
         'soort', 'sorry', 'speciaal', 'speciale', 'speel', 'speelde',
         'speelt', 'spel', 'spelen', 'spelletje', 'spijt', 'spoor', 'sporen',
         'sprak', 'spreek', 'spreekt', 'spreken', 'springen', 'spul',
         'spullen', 'st', 'sta', 'staan', 'staat', 'stad', 'stap', 'stappen',
         'start', 'station', 'steeds', 'steek', 'steen', 'steken', 'stel',
         'stelen', 'stellen', 'stelt', 'stem', 'stemmen', 'stenen', 'ster',
         'sterf', 'sterft', 'sterk', 'sterke', 'sterker', 'sterren', 'sterven',
         'steun', 'steve', 'stierf', 'stil', 'stilte', 'stoel', 'stom',
         'stomme', 'stond', 'stop', 'stoppen', 'stopt', 'storm', 'straat',
         'straf', 'straks', 'strand', 'street', 'strijd', 'stroom', 'stuk',
         'stukje', 'stukken', 'sturen', 'stuur', 'stuurde', 'stuurt', 'succes',
         'sukkel', 'super', 'systeem', 'taak', 'taal', 'taart', 'tafel',
         'talent', 'tanden', 'tante', 'tas', 'taxi', 'te', 'team', 'ted',
         'tegen', 'tegenhouden', 'tegenover', 'teken', 'tekenen', 'telefoon',
         'telefoontje', 'ten', 'tenminste', 'tent', 'tenzij', 'ter', 'terecht',
         'terug', 'terugkomen', 'terwijl', 'test', 'testen', 'teveel',
         'tevreden', 'the', 'thee', 'theorie', 'thomas', 'thuis', 'tien',
         'tijd', 'tijden', 'tijdens', 'tijdje', 'toch', 'toe', 'toegang',
         'toekomst', 'toen', 'toestemming', 'toeval', 'toevallig', 'toilet',
         'tom', 'tommy', 'tonen', 'tong', 'tony', 'toon', 'top', 'tot',
         'totaal', 'totdat', 'trap', 'trein', 'trek', 'trekken', 'trekt',
         'troep', 'trots', 'trouw', 'trouwen', 'trouwens', 'truck', 'trut',
         'tuin', 'tussen', 'tuurlijk', 'tv', 'twaalf', 'twee', 'tweede',
         'twijfel', 'twintig', 'type', 'uh', 'uit', 'uiteindelijk',
         'uitgenodigd', 'uitleggen', 'uitstekend', 'uitzoeken', 'universiteit',
         'up', 'uren', 'uur', 'uw', 'uwe', 'vaak', 'vaarwel', 'vader',
         'vaders', 'vakantie', 'vaker', 'val', 'vallen', 'valt', 'van',
         'vanaf', 'vanavond', 'vandaag', 'vandaan', 'vandoor', 'vangen',
         'vanmorgen', 'vannacht', 'vanuit', 'vanwege', 'vast', 'vasthouden',
         'vecht', 'vechten', 'veel', 'vegas', 'veilig', 'veiligheid', 'veld',
         'vele', 'vent', 'ver', 'veranderd', 'veranderen', 'verandert',
         'verantwoordelijk', 'verband', 'verbergen', 'verboden', 'verborgen',
         'verdachte', 'verder', 'verdiend', 'verdienen', 'verdient',
         'verdieping', 'verdomd', 'verdomde', 'verdomme', 'verdorie',
         'verdwenen', 'verdwijnen', 'vergadering', 'vergeef', 'vergeet',
         'vergeten', 'vergeven', 'vergissing', 'verhaal', 'verhalen',
         'verjaardag', 'verkeerd', 'verkeerde', 'verklaring', 'verkocht',
         'verkoop', 'verkopen', 'verlaat', 'verlaten', 'verleden', 'verliefd',
         'verlies', 'verliest', 'verliezen', 'verloor', 'verloren', 'vermist',
         'vermoord', 'vermoorden', 'vermoordt', 'vernietigd', 'vernietigen',
         'veroorzaakt', 'verpest', 'verraden', 'verrassing', 'verschil',
         'verschillende', 'verschrikkelijk', 'verslaan', 'verstand', 'verstopt',
         'vertaald', 'vertaling', 'vertel', 'verteld', 'vertelde', 'vertellen',
         'vertelt', 'vertrek', 'vertrekken', 'vertrekt', 'vertrokken',
         'vertrouw', 'vertrouwen', 'verwacht', 'verwachten', 'verzoek',
         'via', 'victor', 'video', 'viel', 'vier', 'vieren', 'vijand',
         'vijanden', 'vijf', 'vind', 'vinden', 'vindt', 'vingers', 'virus',
         'vis', 'vissen', 'vlak', 'vlees', 'vliegen', 'vliegtuig', 'vliegveld',
         'vloer', 'vlucht', 'vluchten', 'vlug', 'voedsel', 'voel', 'voelde',
         'voelen', 'voelt', 'voeren', 'voet', 'voeten', 'vogel', 'vol',
         'volg', 'volgen', 'volgende', 'volgens', 'volgt', 'volk', 'volle',
         'volledig', 'volwassen', 'vond', 'vonden', 'voor', 'vooral',
         'voorbij', 'voordat', 'voorkomen', 'voorstellen', 'vooruit',
         'voorzichtig', 'voren', 'vorig', 'vorige', 'vorm', 'vraag', 'vraagt',
         'vragen', 'vrede', 'vreemd', 'vreemde', 'vreselijk', 'vreselijke',
         'vriend', 'vriendelijk', 'vrienden', 'vriendin', 'vriendje', 'vrij',
         'vrijdag', 'vrije', 'vrijheid', 'vroeg', 'vroeger', 'vrouw',
         'vrouwen', 'vuile', 'vuren', 'vuur', 'waar', 'waard', 'waardeer',
         'waardoor', 'waarheid', 'waarin', 'waarmee', 'waarom', 'waarop',
         'waarover', 'waarschijnlijk', 'waarvan', 'waarvoor', 'wacht',
         'wachten', 'wagen', 'wakker', 'walter', 'wanneer', 'want', 'wapen',
         'wapens', 'war', 'ware', 'waren', 'warm', 'was', 'washington',
         'wat', 'water', 'wc', 'we', 'wedstrijd', 'week', 'weekend', 'weer',
         'wees', 'weet', 'weg', 'weggaan', 'wegwezen', 'weinig', 'weken',
         'wel', 'welk', 'welke', 'welkom', 'welterusten', 'wens', 'werd',
         'werden', 'wereld', 'werk', 'werkelijk', 'werken', 'werkt', 'werkte',
         'west', 'westen', 'wet', 'weten', 'wezen', 'wie', 'wiens', 'wij',
         'wijn', 'wijs', 'wil', 'wilde', 'wilden', 'will', 'willen', 'william',
         'wilt', 'wind', 'winkel', 'winnen', 'wint', 'wist', 'wisten', 'wit',
         'witte', 'wonder', 'wonen', 'woon', 'woont', 'woord', 'woorden',
         'word', 'worden', 'wordt', 'wou', 'wow', 'wraak', 'www', 'yeah',
         'york', 'you', 'zaak', 'zag', 'zagen', 'zak', 'zaken',
         'zakken', 'zal', 'zat', 'zaten', 'zaterdag', 'ze', 'zee', 'zeer',
         'zeg', 'zeggen', 'zegt', 'zei', 'zeiden', 'zeker', 'zelf', 'zelfmoord',
         'zelfs', 'zes', 'zet', 'zetten', 'zeven', 'zich', 'zichzelf', 'zie',
         'ziek', 'ziekenhuis', 'ziekte', 'ziel', 'zien', 'ziens', 'ziet',
         'zij', 'zijn', 'zin', 'zingen', 'zit', 'zitten', 'zo',
         'zoals', 'zocht', 'zodat', 'zodra', 'zoek', 'zoeken', 'zoekt',
         'zoiets', 'zojuist', 'zolang', 'zomaar', 'zomer', 'zon', 'zonder',
         'zoon', 'zorg', 'zorgen', 'zorgt', 'zou', 'zouden', 'zoveel',
         'zover', 'zuid', 'zuiden', 'zul', 'zulke', 'zullen', 'zult', 'zus',
         'zuster', 'zwaar', 'zwaard', 'zwak', 'zwanger', 'zware', 'zwart',
         'zwarte', 'zweer', 'zwemmen']
